==> ovirt-engine-3.5.6.2.tar.gz: backend/manager/modules/bll/src/main/java/org/ovirt/engine/core/bll/AddRngDeviceCommand.java <==
package org.ovirt.engine.core.bll;

import org.ovirt.engine.core.bll.context.CommandContext;
import org.ovirt.engine.core.common.action.RngDeviceParameters;
import org.ovirt.engine.core.common.businessentities.VmEntityType;
import org.ovirt.engine.core.common.businessentities.VmRngDevice;
import org.ovirt.engine.core.common.errors.VdcBllMessages;
import org.ovirt.engine.core.compat.Guid;

public class AddRngDeviceCommand extends AbstractRngDeviceCommand<RngDeviceParameters> {

    public AddRngDeviceCommand(RngDeviceParameters parameters) {
        this(parameters, null);
    }

    public AddRngDeviceCommand(RngDeviceParameters parameters, CommandContext commandContext) {
        super(parameters, commandContext);
    }

    protected boolean canDoAction() {
        if (!super.canDoAction()) {
            return false;
        }

        if (getTemplateType() != VmEntityType.INSTANCE_TYPE) {
            if (!validate(getVirtioRngValidator().canAddRngDevice(getVdsGroup(), getParameters().getRngDevice()))) {
                return false;
            }
        }

        if (!getRngDevices().isEmpty()) {
            return failCanDoAction(VdcBllMessages.ACTION_TYPE_FAILED_RNG_ALREADY_EXISTS);
        }

        return true;
    }

    @Override
    protected void executeCommand() {
        VmRngDevice rngDevice = getParameters().getRngDevice();
        if (rngDevice.getDeviceId() == null) {
            rngDevice.setDeviceId(Guid.newGuid());
        }
        getDbFacade().getVmDeviceDao().save(rngDevice);
        setActionReturnValue(rngDevice.getDeviceId());
        setSucceeded(true);
    }

}

==> ovirt-engine-3.6.3.3.tar.gz: backend/manager/modules/bll/src/main/java/org/ovirt/engine/core/bll/AddRngDeviceCommand.java <==
package org.ovirt.engine.core.bll;

import org.ovirt.engine.core.bll.context.CommandContext;
import org.ovirt.engine.core.common.action.RngDeviceParameters;
import org.ovirt.engine.core.common.businessentities.VmEntityType;
import org.ovirt.engine.core.common.businessentities.VmRngDevice;
import org.ovirt.engine.core.common.errors.EngineMessage;
import org.ovirt.engine.core.compat.Guid;

@InternalCommandAttribute
public class AddRngDeviceCommand extends AbstractRngDeviceCommand<RngDeviceParameters> {

    public AddRngDeviceCommand(RngDeviceParameters parameters) {
        this(parameters, null);
    }

    public AddRngDeviceCommand(RngDeviceParameters parameters, CommandContext commandContext) {
        super(parameters, commandContext);
    }

    protected boolean canDoAction() {
        if (!super.canDoAction()) {
            return false;
        }

        if (getTemplateType() != VmEntityType.INSTANCE_TYPE && !isBlankTemplate()) {
            if (!validate(getVirtioRngValidator().canAddRngDevice(getVdsGroup(), getParameters().getRngDevice()))) {
                return false;
            }
        }

        if (!getRngDevices().isEmpty()) {
            return failCanDoAction(EngineMessage.ACTION_TYPE_FAILED_RNG_ALREADY_EXISTS);
        }

        return true;
    }

    @Override
    protected void executeCommand() {
        VmRngDevice rngDevice = getParameters().getRngDevice();
        if (rngDevice.getDeviceId() == null) {
            rngDevice.setDeviceId(Guid.newGuid());
        }
        getDbFacade().getVmDeviceDao().save(rngDevice);
        setActionReturnValue(rngDevice.getDeviceId());
        setSucceeded(true);
    }

}
